@@ -1,6 +1,6 @@
 import inspect
 
-from decorators import before, after, around
+from decorators import before, after, around, patcher
 
 
 class MultipleGeneratorsContextManager(object):
@@ -21,6 +21,14 @@ class MultipleGeneratorsContextManager(object):
 
 class Exam(object):
 
+    @before
+    def setup_patchers(self):
+        # Run the patcher function, and set the results
+        for wrapped in self.attrs_of_type(patcher.wrapper):
+            ptchr = wrapped(self)
+            setattr(self, wrapped.func.__name__, ptchr.start())
+            self.addCleanup(ptchr.stop)
+
     def attrs_of_type(self, kind):
         for base in inspect.getmro(type(self)):
             for value in vars(base).values():
@@ -28,6 +36,7 @@ class Exam(object):
                     yield value
 
     def setUp(self):
+        # Run each before
         for value in self.attrs_of_type(before):
             value(self)
 
